.. image:: https://readthedocs.org/projects/docfly/badge/?version=latest
    :target: https://docfly.readthedocs.io/?badge=latest
    :alt: Documentation Status

.. image:: https://travis-ci.org/MacHu-GWU/docfly-project.svg?branch=master
    :target: https://travis-ci.org/MacHu-GWU/docfly-project?branch=master

.. image:: https://codecov.io/gh/MacHu-GWU/docfly-project/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/MacHu-GWU/docfly-project

.. image:: https://img.shields.io/pypi/v/docfly.svg
    :target: https://pypi.python.org/pypi/docfly

.. image:: https://img.shields.io/pypi/l/docfly.svg
    :target: https://pypi.python.org/pypi/docfly

.. image:: https://img.shields.io/pypi/pyversions/docfly.svg
    :target: https://pypi.python.org/pypi/docfly

.. image:: https://img.shields.io/badge/STAR_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/docfly-project

------


.. image:: https://img.shields.io/badge/Link-Document-blue.svg
      :target: https://docfly.readthedocs.io/index.html

.. image:: https://img.shields.io/badge/Link-API-blue.svg
      :target: https://docfly.readthedocs.io/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Source_Code-blue.svg
      :target: https://docfly.readthedocs.io/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
      :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
      :target: https://github.com/MacHu-GWU/docfly-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
      :target: https://github.com/MacHu-GWU/docfly-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
      :target: https://github.com/MacHu-GWU/docfly-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
      :target: https://pypi.org/pypi/docfly#files


欢迎来到 ``docfly`` 文档
==============================================================================
``docfly`` 能大大减少你用 `sphinx-doc <http://www.sphinx-doc.org/en/stable/index.html>`_ 创建文档的工作.

**功能**:

- 自动生成 API 文档, 包括 模块, 类, 方法, 函数 等.
- 自动为树形文件结构生成子文件引用所需的 ``.. toctree::`` sphinx directive.


.. _install:

Install
------------------------------------------------------------------------------

``docfly`` 已被发布到 PyPI, 你只需要用下面的命令安装:

.. code-block:: console

    $ pip install docfly

升级到最新版本:

.. code-block:: console

    $ pip install --upgrade docfly
